/*
 * Program:    Assertion.java
 * Purpose:    base class for SAML assertion
 * @author     Ray Lai (ray.lai@sun.com)
 * @version    1.0
 * Updated:    April 17, 2005, 1:10 PM
 * Copyright:  (c) 2006 by Ray Lai
 * Remarks:    Full program and documentation will be available under developer.java.net
 * =====================================================================================
 * Design summary
 *   This is a simplified version of a SAML assertion object. It includes only a few
 *   elements such as subjectDNS, subjectIP, sourceSite, destinationSite, and the
 *   extension (e.g. Authentication Statement).
 *   It does not include elements of complex data objects such as Condition, 
 *   Version, Signature, and Advice.
 */
 
package com.csp.identity;

public class Assertion {
        
    protected String subjectDNS;
    protected String subjectIP;
    protected String sourceSite;
    protected String destinationSite;
    protected com.csp.identity.Subject subject;
        
    /** Constructor - Creates a new instance of Assertion */
    /*
    public Assertion(String sourceSite, String destinationSite,       
                     String subjectDNS, String subjectIP) {
        this.subjectDNS = subjectDNS;
        this.subjectIP = subjectIP;
        this.sourceSite = sourceSite;
        this.destinationSite = destinationSite;
    }
    */
    
    /**
     * get subject DNS
     *
     * @return String subject DNS
     **/
    public String getSubjectDNS() {
        return this.subjectDNS;
    }

    /**
     * set subject DNS
     *
     * @param String subject DNS
     **/
    public void setSubjectDNS(String subjectDNS) {
        this.subjectDNS = subjectDNS;
    }

    /**
     * get subject IP
     *
     * @return String subject IP
     **/
    public String getSubjectIP() {
        return this.subjectIP;
    }
    
    /**
     * set subject IP
     *
     * @param String subject IP
     **/
    public void setSubjectIP(String subjectIP) {
        this.subjectIP = subjectIP;
    }

    /**
     * get source site
     *
     * @return String source site
     **/
    public String getSourceSite() {
        return this.sourceSite;
    }

    /**
     * set source site
     *
     * @param String source site
     **/
    public void setSourceSite(String sourceSite) {
        this.sourceSite = sourceSite;
    }

    /**
     * get destination site
     *
     * @return String destination site
     **/
    public String getDestinationSite() {
        return this.destinationSite;
    }

    /**
     * set destination site
     *
     * @param String destination site
     **/
    public void setDestinationSite(String destinationSite) {
        this.destinationSite = destinationSite;
    }
    
    /**
     * get instance of assertion
     *
     * @return com.csp.identity.Assertion instance
     **/
    public com.csp.identity.Assertion getInstance() {
        return this;
    }
    
    /**
     * get subject
     *
     * @return com.csp.identity.Subject subject
     **/
    public com.csp.identity.Subject getSubject() {
        return this.subject;
    }
    
    /**
     * set subject
     *
     * @param com.csp.identity.Subject subject
     **/
    public void setSubject(com.csp.identity.Subject subject) {
        this.subject = subject;
    }
}
