/*
 * Program: AddUser.java
 * Purpose: To illustrate how a SPML request addUser is generated (Example 13-2 in Core Security Patterns pp. 837ff)
 * @author: Ray Lai (ray.lai@sun.com)
 * Updated: June 10, 2005, 11:36 AM
 * Copyright:  (c) 2006 by Ray Lai
 * Remarks:    Full program and documentation will be available under developer.java.net
 *             For simplicity, logger class is removed.
 *
 * This demo shows a simulation of SPML addRequest using home-grown SPML simulation library.
 * If you download OpenSPML (http://www.openspml.org), just uncomment the sample code, and make minor changes as per
 * the commented instructions.
 * You should be able to create similar SPML addUser request.
 * ===================================================================================
 * Constraints - known problem in creating multiple namespaces using JDOM.
 */

package com.csp.provisioning;

import java.util.HashMap;
// for simulation of SPML library; comment these 3 lines if OpenSPML is used
import com.csp.spml.AddRequest;
import com.csp.spml.AddResponse;
import com.csp.spml.SpmlClient;
// Uncomment these if OpenSPML is used
//import org.openspml.client.SpmlClient;
//import org.openspml.message.AddRequest;
//import org.openspml.message.AddResponse;


public class AddUser {
    
    protected SpmlClient client = new SpmlClient();
    protected AddRequest request = new AddRequest();
    protected HashMap userAttr = new HashMap();
    protected AddResponse response;
    
    protected final String url = "http://localhost:8080/lighthouse/servlet/rpcrouter2";
    protected final String firstName = "Mary";
    protected final String lastName = "Parker";
    protected final String fullName = "Mary Jane Parker";
    protected final String password = "peterIsSpidey123";
    protected final String email = "maryj@namredips.com";
    protected final String identifier = "maryjane";
    
    
    
    /**
     * Creates a new instance of AddUser
     */
    public AddUser() {
        
        // uncomment the try/catch statement if OpenSPML library is used
//        try {
        System.out.println("Creating a SPML request to add user");
        create();
        System.out.println("SPML request generation is complete.");
//        } catch (Throwable addUser) {
        // add your exception handling
//            System.out.println(addUser.toString());
//        }
    }
    
    /**
     * Create SPML request for add user
     *
     * @exception Exception ex
     */
    
    //uncomment this create() with Exception if OpenSPML library is used
    //private void create() throws Exception {
    private void create()  {
        this.client.setTrace(true);
        // Use a generic SPML client
        // Assumptions
        // 1. SOAPRouter and TestSpmlHandler are registered using this URL below
        //    customize this URL for your local environment
        // 2. Lighthouse is a resource resembling your SPML server
        this.client.setUrl(this.url);
        
        this.request.setIdentifier(this.identifier);
        this.request.setObjectClass("user");
        
        // define user attributes
        this.userAttr.put("password", this.password);
        this.userAttr.put("email", this.email);
        this.userAttr.put("firstname", this.firstName);
        this.userAttr.put("lastname", this.lastName);
        this.userAttr.put("fullname", this.fullName);
        this.request.setAttributes(userAttr);
        
        // generate SPML request to add user
        response = (AddResponse)this.client.request(request);
        this.client.throwErrors(response);
        
    }
    
    public static void main(String args[]) {
        new AddUser();
    }
}
