/*
 * Program: ServiceConfigContext.java
 * Purpose: To define service config context that depicts the application id, protocol binding and state
 * @author: Ray Lai (ray.lai@sun.com)
 * Updated: May 27, 2005, 12:08 PM
 * Copyright:  (c) 2006 by Ray Lai
 * Remarks:    Full program and documentation will be available under developer.java.net
 *             For simplicity, logger class is removed.
 * ============================================================================================
 */

package com.csp.provisioning;
import java.util.Date;


public class ServiceConfigContext {
    
    protected String applicationId;
    protected String applicationClassName;
    protected String applicationURI;
    protected String protocolBinding;
    protected String requesterId;
    protected String topicName;
    protected Date   updateTimestamp;
    protected int    state;
    //protected List   configProps;

    public static final int SYNC_STATE = 0;
    public static final int NOT_YET_SYNC_STATE = 1;
    public static final int UNKNOWN_STATE = 2;
    public static final int ERROR_STATE = 3;
    
    /** 
     * Constructor - Creates a new instance of ServiceConfigContext 
     *
     *  @param String applicationId
     *  @param String applicationName
     *  @param String protocolBinding
     *  @param int    state
     */
    public ServiceConfigContext(String applicationId, String applicationClassName, String applicationURI, String protocolBinding, int state, String requesterId, String topicName) {
        this.applicationId = applicationId;
        this.applicationClassName = applicationClassName;
        this.applicationURI = applicationURI;
        this.protocolBinding = protocolBinding;
        this.state = state;
        this.requesterId = requesterId;
        this.updateTimestamp = new Date();
        this.topicName = topicName;
    }
    
    /**
     * fetch application id
     * 
     * @return String applicationId
     **/
    public String getApplicationId() {
        return this.applicationId;
    }

    /**
     * fetch application class name
     * 
     * @return String applicationClassName
     **/    
    public String getApplicationClassName() {
        return this.applicationClassName;
    }
    
    /**
     * fetch application URI
     *    - this is unused in the sample code
     *
     * @return String applicationURI
     **/    
    public String getApplicationURI() {
       return this.applicationURI;    
    }
    
    /**
     * fetch application protocol binding
     * 
     * @return String protocolBinding
     **/    
    public String getProtocolBinding() {
        return this.protocolBinding;
    }
    
    /**
     * fetch application state
     * 
     * @return int state
     **/    
    public int getState() {
        return this.state;
    }
    
    /**
     * fetch requester id
     * 
     * @return String requestId
     **/    
    public String getRequesterId() {
        return this.requesterId;
    }
    
    /**
     * fetch update timestamp
     * 
     * @return Date updateTimestamp
     **/    
    public Date getUpdateTimestamp() {
        return this.updateTimestamp;
    }
    
    
    /**
     * fetch topic name. the topic name is the JMS topic where
     *  the SPML request is published to
     * 
     * @return String topicName
     **/    
    public String getTopicName() {
        return this.topicName;
    }
    
    
    /**
     * set application state
     * 
     * @param int state
     **/    
    public void setState(int state) {
        this.state = state;
    }    
}
