/*
 * Program:   AddRequest.java
 * Purpose:   Stub program to simulate SPML add request
 * Updated:   November 7, 2005, 8:04 AM
 * @author    Ray Lai (ray.lai@sun.com)
 * Copyright:  (c) 2006 by Ray Lai
 * Remarks:    Full program and documentation will be available under developer.java.net
 *             For simplicity, logger class is removed.
 * ============================================================================================
 */

package com.csp.spml;

import java.util.HashMap;
import java.util.Iterator;
import org.jdom.Document;
import org.jdom.Element;
import org.jdom.Namespace;
import org.jdom.output.XMLOutputter;


public class AddRequest {
    protected String url = "urlX";
    protected String objectClass = "objectClassX";
    protected String identifier = "identifierX";
    protected Document spmlRequestMessage;
    protected HashMap<String,String> map = new HashMap();
    protected Namespace spmlNamespace = Namespace.getNamespace("spml", "urn:oasis:names:tc:SPML:1:0");
    protected Namespace dsmlNamespace = Namespace.getNamespace("dsml", "urn:oasis:names:tc:DSML:2:0:core");
    
    /** Creates a new instance of AddRequest */
    public AddRequest() {
        this.spmlRequestMessage = createMessage();
    }
    
    /** Create SPML message
     *
     *  @return Document SPMLMessage
     */
    private Document createMessage() {
        try {
           Element addRequest = new Element("addRequest", this.spmlNamespace);
            
            //addRequest.setAttribute("xmlns:spml", "urn:oasis:names:tc:SPML:1:0");
            addRequest.setAttribute("dsml", "urn:oasis:names:tc:DSML:2:0:core");
            
            Element identifier = new Element("identiifer");
            identifier.setAttribute("type", "urn:oasis:names:tc:SPML:1:0#GUID");
            
            Element id = new Element("id");
            id.addContent(this.identifier);
            identifier.addContent(id);
            
            addRequest.addContent(identifier);
            
            spmlRequestMessage = new Document(addRequest);
            
            return spmlRequestMessage;
        } catch (Exception ex) {
            ex.printStackTrace();
        }
        return null;
    }
    
    /* set attributes in the HashMap
     * 
     * @param HashMap map
     */
    public void setAttributes(HashMap map) {

        Element attributes = new Element("attributes", this.spmlNamespace);
        
        for (Iterator it = map.keySet().iterator(); it.hasNext(); ) {
            Object keyName = it.next();
            Object keyValue = map.get(keyName);
            Element attr = new Element("attr", "dsml", "urn:oasis:names:tc:DSML:2:0:core");
            attr.setAttribute("name", (String)keyName);
            
            Element value = new Element("value", "dsml", "urn:oasis:names:tc:DSML:2:0:core");
            value.addContent((String)keyValue);
            attr.addContent(value);
            
            attributes.addContent(attr);
        }
        
        Element rootElement = this.spmlRequestMessage.detachRootElement();
        rootElement.addContent(attributes);
        
        this.spmlRequestMessage = new Document(rootElement);
        
    }
    
    /** set URL
     *
     * @param String url
     */
    public void setUrl(String url) {
        this.url = url;
    }
    
    /** set identifier
     *
     * @param String identifier
     */
    public void setIdentifier(String identifier) {
        this.identifier = identifier;
    }
    
    /** set object class
     *
     * @param String objectClass
     */
    public void setObjectClass(String objectClass) {
        this.objectClass = objectClass;
    }
    
    /** get spml request message
     *
     * @return Document spml message doc
     */
    public Document getSpmlRequest() {
        return this.spmlRequestMessage;
    }
    
    /** converted SPML message to string
     *
     * @return String spml message
     */
    public String toString() {
        XMLOutputter serializer = new XMLOutputter();
        return (serializer.outputString(this.spmlRequestMessage));
    }
    
}
